<?php
defined('ABSPATH') or die("No script kiddies please!");
/**
 * Plugin Name: Swift Demo Import
 * Plugin URI: http://www.paglithemes.com/swift-demo-import
 * Description: A Plugin to import wordpress contents, customizer settings and widgets.
 * Version: 1.0.1
 * Author: bnayawpguy
 * Author URI: http://paglithemes.com
 * Text Domain: swift-demo-import
 * Domain Path: /languages/
 * License:GPLv2 or later
 * */

if(!class_exists('SWFT_Demo_Import')) :
    require_once plugin_dir_path( __FILE__ ) . 'importer/swift-importer.php';
    class SWFT_Demo_Import extends SWFT_Import{
        public $demos;

        /** Initializing Plugin Constructor **/
        function __construct() {
            /** Defining Necessary Constants **/
            $this->define_constants();

            /** Assign Default Values **/
            $this->demos = array();

            /** Enqueue Scripts & Styles **/
            add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_styles' ) );

            /** Demo Import Section **/
            add_action('swift_demo_import', array($this, 'demo_importer') );

            /** Import Demo **/
            add_action( 'wp_ajax_import_demo', array( $this, 'import_demo_cb' ) );
            
        }

        /**
         * Declartion of necessary constants for plugin
         * */ 
        function define_constants() {

            defined( 'SWFT_DIMPORT_VERSION' ) or define( 'SWFT_DIMPORT_VERSION', '1.0.1' ); //plugin version
            defined( 'SWFT_DIMPORT_TD' ) or define( 'SWFT_DIMPORT_TD', 'pagli-companion' ); //plugin's text domain
            defined( 'SWFT_DIMPORT_DIR' ) or define( 'SWFT_DIMPORT_DIR', plugin_dir_url( __FILE__ ) );  //plugin js directory
            defined( 'SWFT_DIMPORT_JS_DIR' ) or define( 'SWFT_DIMPORT_JS_DIR', plugin_dir_url( __FILE__ ) . 'js/' );  //plugin js directory
            defined( 'SWFT_DIMPORT_CSS_DIR' ) or define( 'SWFT_DIMPORT_CSS_DIR', plugin_dir_url( __FILE__ ) . 'css/' ); // plugin css dir
            defined( 'SWFT_DIMPORT_PATH' ) or define( 'SWFT_DIMPORT_PATH', plugin_dir_path( __FILE__ ) ); // plugin path
            defined( 'SWFT_DIMPORT_LANG_DIR' ) or define( 'SWFT_DIMPORT_LANG_DIR', plugin_dir_path( __FILE__ ) ); // plugin language directory
        }

        public function enqueue_styles() {
            wp_enqueue_style( 'font-awesome', SWFT_DIMPORT_CSS_DIR . 'faw/css/font-awesome.css' );
            wp_enqueue_style( 'swift-demo-import', SWFT_DIMPORT_CSS_DIR . 'demo-import.css' );
            wp_enqueue_script( 'swift-demo-import', SWFT_DIMPORT_JS_DIR . 'demo-import.js' );
            $localizes = array(
                'ajaxurl' => esc_url( admin_url( 'admin-ajax.php' ) ),
                'installing_txt' => esc_html__('Installing . . .', 'swift-demo-import'),
                'success_notif' => esc_html__( 'Demo has been Successfully Installed!', 'swift-demo-import' ),
            );
            wp_localize_script( 'swift-demo-import', 'swftImport', $localizes);
        }

        public function demo_importer() {
            $demos = $this->demos;
            if(!empty($demos)) {
                foreach($demos as $demo) {
                    extract($demo);
                    
                    $smenu = '';
                    if(!empty($menu)) {
                        foreach($menu as $label => $id) {
                            $smenu .=$label.'>'.$id.'|';
                        }
                    }

                    $demo_data = json_encode( array(
                        'xml_file' => esc_attr($xml_file),
                        'widget_file' => esc_attr($widget_file),
                        'customizer_file' => esc_attr($customizer_file),
                        'home_page' => esc_attr($home_page),
                        'blog_page' => esc_attr($blog_page),
                        'menu' => esc_attr($smenu),
                    ) );
                    ?>
                    <div class="demo-wrap clearfix">
                        <?php if($preview_image != '') : ?>
                        <div class="preview-image">
                            <img src="<?php echo esc_url($preview_image); ?>" />    
                        </div>
                        <?php endif; ?>

                        <?php if($title) : ?>
                        <h3 class="demo-title"><?php echo esc_html($title); ?></h3>
                        <?php endif; ?>

                        <div class="demo-action-btn">
                            <a class="demo-install btn" href="javascript(void);" data-demo="<?php echo esc_attr($demo_data); ?>"><?php echo esc_html__( 'Install Demo', 'swift-demo-import' ) ?></a>
                            <a class="demo-preview btn" target="_blank" href="<?php echo esc_url($preview_link); ?>"><?php echo esc_html__( 'Preview Demo', 'swift-demo-import' ) ?></a>
                        </div>
                    </div>
                    <?php
                }
            }
        }

        /** Function to Set the featured Home Page **/
        public function set_home_blog_page($homepage, $blogpage) {

            if($homepage || $blogpage) {
                update_option( 'show_on_front', 'page' );

                /** Setting Home Page **/
                if($homepage) {
                    $fpage = get_page_by_path( $homepage );
                    update_option( 'page_on_front', $fpage->ID);
                }

                /** Setting Blog Page **/
                if($blogpage) {
                    $bpage = get_page_by_path( $blogpage );
                    update_option( 'page_for_posts', $bpage->ID);
                }

            }

            return '';
        }

        /** Function to set the Menus **/
        public function set_menus($menu) {
            if( $menu != '' ) {
                global $wpdb;
                $table_db_name = $wpdb->prefix . "terms";
                $menu_ids = array();
                $save_menu = array();
                $menu = rtrim($menu, '|');
                $menu_arr = explode('|', $menu);

                foreach($menu_arr as $menu_single_ar) {
                    $mens = explode('&gt;', $menu_single_ar);
                    $rows = $wpdb->get_results("SELECT * FROM $table_db_name where name='".$mens[0]."'",ARRAY_A);

                    foreach($rows as $row) {
                        $menu_ids[$row["name"]] = $row["term_id"] ;
                    }
                    if ( has_nav_menu( $mens[0] ) ) {
                         continue;
                    }
                    else {
                        $save_menu[$mens[1]] = $menu_ids[$mens[0]];
                    }
                    $save_menu[$mens[1]] = $menu_ids[$mens[0]];
                }
                set_theme_mod('nav_menu_locations', $save_menu);
            }

            return '';
        }

        /** Function to Import Demo **/
        public function import_demo_cb() {
            $xml_file = isset($_REQUEST['xml_file']) ? esc_attr($_REQUEST['xml_file']) : '';
            $widget_file = isset($_REQUEST['widget_file']) ? esc_attr($_REQUEST['widget_file']) : '';
            $customizer_file = isset($_REQUEST['customizer_file']) ? esc_attr($_REQUEST['customizer_file']) : '';
            $menu = isset($_REQUEST['menu']) ? esc_attr($_REQUEST['menu']) : '';
            $home_page = isset($_REQUEST['home_page']) ? esc_attr($_REQUEST['home_page']) : '';
            $blog_page = isset($_REQUEST['blog_page']) ? esc_attr($_REQUEST['blog_page']) : '';

            // Import WordPress Contents
            $this->fetch_attachments = true;
            $this->import($xml_file);

            // Import Widget Contents
            $this->widget_import($widget_file);

            // Import Customizer Settings
            $this->customizer_import($customizer_file);

            // Set Menus
            $this->set_menus($menu);

            // Set Home Page and Blog Page
            $this->set_home_blog_page($home_page, $blog_page);

            echo "success";
            
            die();
        }
    }

    new SWFT_Demo_Import;
endif;